@@ -8,7 +8,7 @@ REGEX_PATTERNS = {
 
 CLI_COMMANDS_HELP = {
     'parameter': {
-        'add': """Add a parameter to a context, or update a parameter If it is already existing in the context.\n
+        'add': """Add a parameter to a context, or update a parameter if it is already existing in the context.\n
                 ** Tips: 1) If the parameter is inherited from the parent contexts, it will be overriden in the context. 2) Multiple parameters may be added at once using the '--input' option.\n
                 KEY: The identifier of the parameter to be added. It may also be provided using the '--key' option.\n
                 VALUE: The value for the parameter. If the parameter is already existing in the context, the value will be updated to the new one. It may also be provided using the '--value' option.\n
@@ -20,13 +20,18 @@ CLI_COMMANDS_HELP = {
                 ** Tips: 1) The parameter may be inherited from the parent contexts or owned by the given context.\n
                 KEY: The identifier of the parameter. It may also be provided using the '--key' option.\n
                 """,
+        'history': """Return the revision history of parameter.\n
+                ** Tips: 1) The parameter may be inherited from the parent contexts or owned by the given context.\n
+                KEY: The identifier of the parameter. It may also be provided using the '--key' option.\n
+                """,
+
         'delete': """Delete a parameter from a context.\n
-                ** Tips: 1) The inherited parameters cannot be deleted. In other words, the context must be the owner of the parameter or a not found error will be returned. 2) Multiple parameters may be deleted at once using the '--input' option.\n         
+                ** Tips: 1) The inherited parameters cannot be deleted. The context must be the owner of the parameter or a not found error will be returned. 2) Multiple parameters may be deleted at once using the '--input' option.\n         
                 KEY: The identifier of the parameter to be deleted. It may also be provided using the '--key' option.\n
-                """,                
+                """,
     },
     'secret': {
-        'add': """Add a secret to a context, or update a secret If it is already existing in the context.\n
+        'add': """Add a secret to a context, or update a secret if it is already existing in the context.\n
                 ** Tips: 1) If the secret is inherited from the parent contexts, it will be overriden in the context. 2) Multiple secrets may be added at once using the '--input' option.\n
                 KEY: The identifier of the secret to be added. It may also be provided using the '--key' option.\n
                 VALUE: The value for the secret. If the secret is already existing in the context, the value will be updated to the new one. It may also be provided using the '--value' option.\n
@@ -39,11 +44,53 @@ CLI_COMMANDS_HELP = {
                 KEY: The identifier of the secret. It may also be provided using the '--key' option.\n
                 """,
         'delete': """Delete a secret from a context.\n
-                ** Tips: 1) The inherited secrets cannot be deleted. In other words, the context must be the owner of the secret or a not found error will be returned. 2) Multiple secrets may be deleted at once using the '--input' option.\n         
+                ** Tips: 1) The inherited secrets cannot be deleted. The context must be the owner of the secret or a not found error will be returned. 2) Multiple secrets may be deleted at once using the '--input' option.\n         
                 KEY: The identifier of the secret to be deleted. It may also be provided using the '--key' option.\n
-                """,                
+                """,
     },
+    'template': {
+        'add': """Add a template to a context, or update the contents if it is already existing in the context.\n
+                ** Tips: 1) If the template is inherited from the parent contexts, it will be overriden in the context. 2) Multiple templates may be added recursively from a directory.\n
+                KEY: The identifier of the template to be added. It may also be provided using the '--key' option.\n
+                """,
+        'list': """Return the list of templates in a context.\n
+                ** Tips: 1) To limit the list to the owned/overriden templates only, use the '--uninherited' option. This will return only the context specific templates.
+                """,
+        'get': """Return the content of a template.\n
+                ** Tips: 1) The template may be inherited from the parent contexts or owned by the given context.\n
+                KEY: The identifier of the secret. It may also be provided using the '--key' option.\n
+                """,
+        'delete': """Delete a template from a context.\n
+                ** Tips: 1) The inherited template cannot be deleted. The context must be the owner of the secret or a not found error will be returned. 2) Multiple templates may be deleted at once using the '--input' option.\n
+                KEY: The identifier of the template to be deleted. It may also be provided using the '--key' option.\n
+                """,
+        'render': """Render templates in a context.\n
+                    """,
+        },
+    'config': {
+        'get': """Get DSO application configuration.\n
+                ** Tips: 1) Use --local or --global to get local or global configuration only.\n
+                KEY: The key of the configuration
+                """,
+        'set': """Set DSO application configuration.\n
+                ** Tips: 1) Use --local or --global to get local or global configuration only.\n
+                KEY: The key of the configuration. It may also be provided using the '--key' option.\n
+                VALUE: The value for the configuration. It may also be provided using the '--value' option.\n
+                """,
+        'delete': """Get DSO application configuration.\n
+                ** Tips: 1) Use --local or --global to get local or global configuration only.\n
+                KEY: The key of the configuration
+                """,
+        'init': """Initialize DSO configuration for the working directory.\n
+                ** Tips: 1) Use --input to load connfiguration from a file.\n
+                The option '--working-dir' can be used to specify a different working directory than the current directory where dso is running in.\n
+                """
+
+
+
+    }
 }
+
 CLI_COMMANDS_SHORT_HELP = {
     'version': "Display versions.",
     'parameter': {
@@ -51,6 +98,7 @@ CLI_COMMANDS_SHORT_HELP = {
         'add': "Add one or multiple parameters to the application.",
         'get': "Get the value of a parameter.",
         'delete': "Delete one or multiple parameters from an application.",
+
     },
     'secret': {
         'list': "List secrets added to the application.",
@@ -100,13 +148,17 @@ CLI_PARAMETERS_HELP = {
         'value': "The value for the parameter. See VALUE argument for more details.",
         'query_values': "Include parameter values in the output.",
         'uninherited': "Select only parameters which are specific to the gievn context, i.e. not inherited from the parent contexts.",
+        'revision': "The revision ID whose value to be fetched.",
+        'history': "Get the revision history of the parameter.",
 
     },
     'secret': {
         'key': "The key of the secret",
         'value': "The value for the secret",
         'query_values': "Include secret values in the output.",
-        'uninherited': "Select only secrets which are specific to the gievn context, i.e. not inherited from the parent contexts."
+        'uninherited': "Select only secrets which are specific to the gievn context, i.e. not inherited from the parent contexts.",
+        'revision': "The revision ID whose value to be fetched.",
+        'history': "Get the revision history of the secret.",
     },
     'template': {
         'type': "Type of the template. Use 'resource' for templates needed at the provision time when provisioning resources required by the application to run such as SQS queus, SNS topics, and CI/CD piplines.\nUse 'package' for templates needed at the build time when generating a package.\nUse 'release' for templates needed at the deploy time when generating a release." ,
@@ -116,6 +168,8 @@ CLI_PARAMETERS_HELP = {
         'query_render_path': "Include the template render paths in the output.",
         'input' : "Path to a local file containing the template content.",
         'recursive' : "Add files recursively.",
+        'uninherited': "Select only templates which are specific to the gievn context, i.e. not inherited from the parent contexts.",
+
     },
     'config': {
         'key': "The key of the configuration",
@@ -144,8 +198,16 @@ CLI_MESSAGES = {
     'AtleastOneofTwoNeeded': "At least one of {0} or {1} must be provided.",
     'MissingOption': "Missing option {0}.",
     'MissingArgument': "Missing argument {0}.",
-    'ArgumentsMutualExclusive': "Either {0} or {1} must be provided, but not both.",
-    'ArgumentsMutualInclusive': "{0} is needed when {1} is provided.",
+    'ArgumentsOnlyOneProvided': "Only one of the following arguments/options may be provided: {0}",
+    'ArgumentsAtLeastOneProvided': "At least one of the following arguments/options must be provided: {0}",
+    'ArgumentsAllProvided': "All of the following arguments/options must be provide: {0}",
+    'ArgumentsNoneProvided': "The following arguments/options cannot be provided: {0}",
+    'ArgumentsNotAllProvided': "The following arguments/options cannot be provided together: {0}",
+    'ArgumentsOnlyOneProvidedBecause': "Becasue {0} provided, only one of the following arguments/options may be provided: {1}",
+    'ArgumentsAtLeastOneProvidedBecause': "Becasue {0} provided, at least one of the following arguments/options must also be provided: {1}",
+    'ArgumentsAllProvidedBecause': "Becasue {0} provided, all of the following arguments/options must also be provide: {1}",
+    'ArgumentsNoneProvidedBecause': "Becasue {0} provided, the following arguments/options cannot be provided: {1}",
+    'ArgumentsNotAllProvidedBecasue': "Becasue {0} provided, the following arguments/options may be provided together: {1}",
     'TemplateNotFound': "Template '{0}' not found.",
     'InvalidTemplateKey': "'{0}' is an invalid template key. Must conform to '{1}'",
     'ContextNotFoundListingInherited': "Context '{0}' not found, listing inherited parameters if any.",
@@ -153,7 +215,7 @@ CLI_MESSAGES = {
     'TryHelp': "Try the command with '-h' / '--help' option for more details.",
     'InvalidJsonFile': "Invalid json file.",
     'InvalidYamlFile': "Invalid yaml file.",
-    'InvalidFileFormat': "Invalid file, not conforming to expected {0} format.",
+    'InvalidFileFormat': "Invalid file, not conforming to the expected '{0}' format.",
     'ArgumentsOrOption': "{0} may be provider via either argument {1} or option {2}, but not both.",
     'LoadingParameters': "Loading parameters...",
     'LoadingSecrets': "Loading secrets...",
@@ -176,6 +238,6 @@ CLI_MESSAGES = {
     'InvalidRenderPathAbs': "'{0}' is not a valid render path becasue render path must be relative to the root of the DSO application.",
     'QueryOptionCompatibleFormats': "Option '-q' / '--query' can be used only with 'json'/'yaml' output formats.",
     'QueryAllOptionNonCompatibleFormats': "Option '-a'/ '--query-all' cannot be used with 'shell' output format.",
-    'MissingCSVField': "Field '{0}' is missing.", 
+    'MissingField': "Field '{0}' is missing.",
     'FileNotFound': "File '{0}' not found.",
 }
