@@ -15,11 +15,15 @@ class ParameterProvider(StoreProvider):
 
 class ParametersClass():
 
+    def validate_key(self, key):
+        provider = ProviderManager.ParameterProvider()
+        Logger.info("Start validating parameter key...")
+        return provider.validate_key(key)
+
     def list(self, stage, uninherited):
         project = Config.project
         application = Config.application
         provider = ProviderManager.ParameterProvider()
-        # Logger.debug("Parameter provider '{0}' used.".format(provider.id))
         if uninherited:
             Logger.info(f"Start listing uninherited SSM parameters: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
@@ -31,33 +35,31 @@ class ParametersClass():
         project = Config.project
         application = Config.application
         provider = ProviderManager.ParameterProvider()
-        # Logger.debug("Parameter provider '{0}' used.".format(provider.id))
         Logger.info(f"Start adding parameter: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}, value={value}")
         return provider.add(project, application, stage, key, value)
 
-    def get(self, stage, key):
+    def get(self, stage, key, revision):
         # self.validate_key(key)
         project = Config.project
         application = Config.application
         provider = ProviderManager.ParameterProvider()
-        # Logger.debug("Parameter provider '{0}' used.".format(provider.id))
-        Logger.info(f"Start getting parameter: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
-        return provider.get(project, application, stage, key)
+        Logger.info(f"Start getting parameter value: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        return provider.get(project, application, stage, key, revision)
+
+    def history(self, stage, key):
+        # self.validate_key(key)
+        project = Config.project
+        application = Config.application
+        provider = ProviderManager.ParameterProvider()
+        Logger.info(f"Start getting parameter history: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+        return provider.history(project, application, stage, key)
 
     def delete(self, stage, key):
         # self.validate_key(key)
         project = Config.project
         application = Config.application
         provider = ProviderManager.ParameterProvider()
-        # Logger.debug("Parameter provider '{0}' used.".format(provider.id))
         Logger.info(f"Start deleting parameter: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
         return provider.delete(project, application, stage, key)
 
-    def validate_key(self, key):
-        provider = ProviderManager.ParameterProvider()
-        # Logger.debug("Parameter provider '{0}' used.".format(provider.id))
-        Logger.info("Start validating parameter key...")
-        return provider.validate_key(key)
-
-
 Parameters = ParametersClass()
\ No newline at end of file
